@@ -22,28 +22,28 @@
 #' current state on the git server, simulating [git_pull].
 #' @inheritParams git_open
 #' @inheritParams git_branch
-git_rebase_list <- function(upstream = NULL, repo = '.'){
+git_rebase_list <- function(upstream = NULL, repo = '.') {
   git_rebase(upstream = upstream, commit_changes = FALSE, repo = repo)
 }
 
 #' @export
 #' @rdname git_rebase
-git_rebase_commit <- function(upstream = NULL, repo = '.'){
+git_rebase_commit <- function(upstream = NULL, repo = '.') {
   git_rebase(upstream = upstream, commit_changes = TRUE, repo = repo)
 }
 
 #' @useDynLib gert R_git_rebase
-git_rebase <- function(upstream, commit_changes, repo){
+git_rebase <- function(upstream, commit_changes, repo) {
   repo <- git_open(repo)
   info <- git_info(repo = repo)
-  if(!length(upstream)){
-    if(!length(info$upstream) || is.na(info$upstream) || !nchar(info$upstream))
+  if (!length(upstream)) {
+    if (!length(info$upstream) || is.na(info$upstream) || !nchar(info$upstream))
       stop("No upstream configured for current HEAD")
     git_fetch(info$remote, repo = repo)
     upstream <- info$upstream
   }
   df <- .Call(R_git_rebase, repo, upstream, commit_changes)
-  if(commit_changes){
+  if (commit_changes) {
     new_head <- ifelse(nrow(df) > 0, utils::tail(df$commit, 1), upstream[1])
     git_branch_set_target(ref = new_head, repo = repo)
     inform("Resetting %s to %s", info$shorthand, new_head)
@@ -53,9 +53,9 @@ git_rebase <- function(upstream, commit_changes, repo){
 
 #' Reset your repo to a previous state
 #'
-#' * `git_reset_hard()` reverts to a point in history
-#' * `git_reset_soft()` uncommits changes, but keeps the chsange uncommited
-#' * `git_reset_mixed()` performs a simple `git reset`.
+#' * `git_reset_hard()` resets the index and working tree
+#' * `git_reset_soft()` does not touch the index file or the working tree
+#' * `git_reset_mixed()` resets the index but not the working tree.
 #'
 #' @family git
 #' @inheritParams git_rebase
@@ -63,24 +63,28 @@ git_rebase <- function(upstream, commit_changes, repo){
 #' @export
 #' @name git_reset
 #' @rdname git_reset
-git_reset_hard <- function(ref = "HEAD", repo = "."){
+git_reset_hard <- function(ref = "HEAD", repo = ".") {
   git_reset("hard", ref = ref, repo = repo)
 }
 
 #' @export
 #' @rdname git_reset
-git_reset_soft <- function(ref = "HEAD", repo = "."){
+git_reset_soft <- function(ref = "HEAD", repo = ".") {
   git_reset("soft", ref = ref, repo = repo)
 }
 
 #' @export
 #' @rdname git_reset
-git_reset_mixed <- function(ref = "HEAD", repo = "."){
+git_reset_mixed <- function(ref = "HEAD", repo = ".") {
   git_reset("mixed", ref = ref, repo = repo)
 }
 
 #' @useDynLib gert R_git_reset
-git_reset <- function(type = c("soft", "hard", "mixed"), ref = "HEAD", repo = "."){
+git_reset <- function(
+  type = c("soft", "hard", "mixed"),
+  ref = "HEAD",
+  repo = "."
+) {
   typenum <- switch(match.arg(type), soft = 1L, mixed = 2L, hard = 3L)
   repo <- git_open(repo)
   ref <- as.character(ref)
@@ -92,7 +96,7 @@ git_reset <- function(type = c("soft", "hard", "mixed"), ref = "HEAD", repo = ".
 #' @rdname git_rebase
 #' @useDynLib gert R_git_cherry_pick
 #' @param commit id of the commit to cherry pick
-git_cherry_pick <- function(commit, repo = '.'){
+git_cherry_pick <- function(commit, repo = '.') {
   repo <- git_open(repo)
   assert_string(commit)
   .Call(R_git_cherry_pick, repo, commit)
@@ -101,11 +105,9 @@ git_cherry_pick <- function(commit, repo = '.'){
 #' @export
 #' @rdname git_rebase
 #' @useDynLib gert R_git_ahead_behind
-git_ahead_behind <- function(upstream = NULL, ref = 'HEAD', repo = '.'){
+git_ahead_behind <- function(upstream = NULL, ref = 'HEAD', repo = '.') {
   repo <- git_open(repo)
-  if(!length(upstream))
-    upstream <- git_info(repo = repo)$upstream
-  if(!length(upstream))
-    stop("No upstream set or specified")
+  if (!length(upstream)) upstream <- git_info(repo = repo)$upstream
+  if (!length(upstream)) stop("No upstream set or specified")
   .Call(R_git_ahead_behind, repo, ref, upstream)
 }
